@@ -10,7 +10,7 @@ def remove_chache_folders(current_repo: str = ""):
         current_repo: repository to clear
     """
     if current_repo == "":
-        new_refs = [elem for elem in os.listdir()]
+        new_refs = [elem for elem in os.listdir(os.getcwd())]
     else:
         new_refs = [current_repo + "/" + elem for elem in os.listdir(current_repo)]
     for elem in new_refs:
